# Personal Knowledge Base


# Prerequisites
1. Python >=3.12.7


# Installation 
1. git clone https://github.com/hyw208/pkb.git to get the 'content' folder and its md files
2. cd pkb
3. python -m venv .venv
4. source .venv/bin/activate 
5. pip install pkb 
   

# To Launch 
1. python -m pkb.fast
2. uvicorn pkb.fast:app (not working sometimes... fixing it)
3. 